@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class SieveDateSpinBoxTest : public QObject
     Q_OBJECT
 public:
     explicit SieveDateSpinBoxTest(QObject *parent = nullptr);
-    ~SieveDateSpinBoxTest() = default;
+    ~SieveDateSpinBoxTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldAssignValue_data();
