@@ -1,20 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactionnotify.h"
+#include "autocreatescripts/autocreatescriptutil_p.h"
 #include "editor/sieveeditorutil.h"
 #include "widgets/selectimportancecombobox.h"
-#include "autocreatescripts/autocreatescriptutil_p.h"
 
 #include <KLocalizedString>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QLineEdit>
 
+#include "libksieve_debug.h"
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QXmlStreamReader>
-#include "libksieve_debug.h"
 
 using namespace KSieveUi;
 
@@ -25,20 +26,21 @@ SieveActionNotify::SieveActionNotify(SieveEditorGraphicalModeWidget *sieveGraphi
 
 QWidget *SieveActionNotify::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *lay = new QHBoxLayout;
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout;
     lay->setContentsMargins({});
     w->setLayout(lay);
 
-    auto *importanceCombobox = new SelectImportanceCombobox;
+    auto importanceCombobox = new SelectImportanceCombobox;
     importanceCombobox->setObjectName(QStringLiteral("importancecombo"));
     connect(importanceCombobox, &SelectImportanceCombobox::valueChanged, this, &SieveActionNotify::valueChanged);
     lay->addWidget(importanceCombobox);
 
-    QLabel *lab = new QLabel(i18n("message:"));
+    auto lab = new QLabel(i18n("message:"));
     lay->addWidget(lab);
 
-    auto *message = new QLineEdit;
+    auto message = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(message, w);
     message->setObjectName(QStringLiteral("message"));
     connect(message, &QLineEdit::textChanged, this, &SieveActionNotify::valueChanged);
     lay->addWidget(message);
@@ -46,7 +48,8 @@ QWidget *SieveActionNotify::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("method:"));
     lay->addWidget(lab);
 
-    auto *method = new QLineEdit;
+    auto method = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(method, w);
     method->setObjectName(QStringLiteral("method"));
     lay->addWidget(method);
     connect(method, &QLineEdit::textChanged, this, &SieveActionNotify::valueChanged);
@@ -63,13 +66,13 @@ void SieveActionNotify::setParamWidgetValue(QXmlStreamReader &element, QWidget *
             if (tagValue == QLatin1String("message")) {
                 const QString strValue = AutoCreateScriptUtil::strValue(element);
                 if (!strValue.isEmpty()) {
-                    auto *message = w->findChild<QLineEdit *>(QStringLiteral("message"));
+                    auto message = w->findChild<QLineEdit *>(QStringLiteral("message"));
                     message->setText(AutoCreateScriptUtil::quoteStr(strValue));
                 }
             } else if (tagValue == QLatin1String("importance")) {
                 const QString strValue = AutoCreateScriptUtil::strValue(element);
                 if (!strValue.isEmpty()) {
-                    auto *importance = w->findChild<SelectImportanceCombobox *>(QStringLiteral("importancecombo"));
+                    auto importance = w->findChild<SelectImportanceCombobox *>(QStringLiteral("importancecombo"));
                     importance->setCode(strValue, name(), error);
                 }
             } else {
@@ -78,12 +81,12 @@ void SieveActionNotify::setParamWidgetValue(QXmlStreamReader &element, QWidget *
             }
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             element.skipCurrentElement();
-            //implement in the future ?
+            // implement in the future ?
         } else if (tagName == QLatin1String("str")) {
-            auto *method = w->findChild<QLineEdit *>(QStringLiteral("method"));
+            auto method = w->findChild<QLineEdit *>(QStringLiteral("method"));
             method->setText(AutoCreateScriptUtil::quoteStr(element.readElementText()));
         } else {
             unknownTag(tagName, error);
