@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,13 +7,14 @@
 #define SELECTVACATIONCOMBOBOX_H
 #include <QComboBox>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SelectVacationComboBox : public QComboBox
 {
     Q_OBJECT
 public:
     explicit SelectVacationComboBox(QWidget *parent = nullptr);
-    ~SelectVacationComboBox();
+    ~SelectVacationComboBox() override;
 
     Q_REQUIRED_RESULT QString code() const;
     void setCode(const QString &code, const QString &name, QString &error);
