@@ -1,20 +1,20 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditionheader.h"
-#include "autocreatescripts/commonwidgets/selectmatchtypecombobox.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
-#include "widgets/selectheadertypecombobox.h"
+#include "autocreatescripts/commonwidgets/selectmatchtypecombobox.h"
 #include "editor/sieveeditorutil.h"
+#include "widgets/selectheadertypecombobox.h"
 
 #include <KLocalizedString>
 
+#include "libksieve_debug.h"
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QXmlStreamReader>
-#include "libksieve_debug.h"
 
 using namespace KSieveUi;
 
@@ -25,25 +25,25 @@ SieveConditionHeader::SieveConditionHeader(SieveEditorGraphicalModeWidget *sieve
 
 QWidget *SieveConditionHeader::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *lay = new QHBoxLayout;
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout;
     lay->setContentsMargins({});
     w->setLayout(lay);
 
-    auto *matchTypeCombo = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
+    auto matchTypeCombo = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     matchTypeCombo->setObjectName(QStringLiteral("matchtypecombobox"));
     connect(matchTypeCombo, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionHeader::valueChanged);
     lay->addWidget(matchTypeCombo);
 
-    auto *grid = new QGridLayout;
+    auto grid = new QGridLayout;
     lay->addLayout(grid);
 
-    auto *headerType = new SelectHeaderTypeComboBox;
+    auto headerType = new SelectHeaderTypeComboBox;
     headerType->setObjectName(QStringLiteral("headertype"));
     connect(headerType, &SelectHeaderTypeComboBox::valueChanged, this, &SieveConditionHeader::valueChanged);
     grid->addWidget(headerType, 0, 0, 1, 2);
 
-    QLabel *lab = new QLabel(i18n("With value:"));
+    auto lab = new QLabel(i18n("With value:"));
     grid->addWidget(lab, 1, 0);
 
     AbstractRegexpEditorLineEdit *value = AutoCreateScriptUtil::createRegexpEditorLineEdit();
@@ -68,7 +68,7 @@ QString SieveConditionHeader::code(QWidget *w) const
 
     valueStr = AutoCreateScriptUtil::fixListValue(valueStr);
     return AutoCreateScriptUtil::negativeString(isNegative) + QStringLiteral("header %1 %2 %3").arg(matchString, headerStr, valueStr)
-           + AutoCreateScriptUtil::generateConditionComment(comment());
+        + AutoCreateScriptUtil::generateConditionComment(comment());
 }
 
 QString SieveConditionHeader::help() const
@@ -88,15 +88,15 @@ void SieveConditionHeader::setParamWidgetValue(QXmlStreamReader &element, QWidge
             if (tagValue == QLatin1String("comparator")) {
                 qCWarning(LIBKSIEVE_LOG) << " comparator support not implemented yet!";
             } else {
-                auto *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
+                auto selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtypecombobox"));
                 selectMatchCombobox->setCode(AutoCreateScriptUtil::tagValueWithCondition(tagValue, notCondition), name(), error);
             }
         } else if (tagName == QLatin1String("str")) {
             if (index == 0) {
-                auto *headerType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertype"));
+                auto headerType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertype"));
                 headerType->setCode(element.readElementText());
             } else if (index == 1) {
-                auto *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
+                auto value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
                 QString st = AutoCreateScriptUtil::quoteStr(element.readElementText(), true);
                 value->setCode(st);
             } else {
@@ -105,12 +105,12 @@ void SieveConditionHeader::setParamWidgetValue(QXmlStreamReader &element, QWidge
             }
             ++index;
         } else if (tagName == QLatin1String("list")) {
-            //Header list
+            // Header list
             if (index == 0) {
-                auto *headerType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertype"));
+                auto headerType = w->findChild<SelectHeaderTypeComboBox *>(QStringLiteral("headertype"));
                 headerType->setCode(AutoCreateScriptUtil::listValueToStr(element));
             } else if (index == 1) {
-                auto *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
+                auto value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
                 value->setCode(AutoCreateScriptUtil::listValueToStr(element));
             } else {
                 tooManyArguments(tagName, index, 2, error);
@@ -119,7 +119,7 @@ void SieveConditionHeader::setParamWidgetValue(QXmlStreamReader &element, QWidge
             ++index;
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
         } else {
