@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,16 +7,17 @@
 #ifndef SIEVEDATESPINBOX_H
 #define SIEVEDATESPINBOX_H
 
-#include <QSpinBox>
-#include "selectdatewidget.h"
 #include "ksieveui_private_export.h"
-namespace KSieveUi {
+#include "selectdatewidget.h"
+#include <QSpinBox>
+namespace KSieveUi
+{
 class KSIEVEUI_TESTS_EXPORT SieveDateSpinBox : public QSpinBox
 {
     Q_OBJECT
 public:
     explicit SieveDateSpinBox(QWidget *parent = nullptr);
-    ~SieveDateSpinBox();
+    ~SieveDateSpinBox() override;
     void setType(KSieveUi::SelectDateWidget::DateType type);
 
     void setRange(int minValue, int maxValue);
