@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -15,7 +15,8 @@ class QXmlStreamReader;
 class QToolButton;
 class QComboBox;
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveCondition;
 class SieveHelpButton;
 class SieveEditorGraphicalModeWidget;
@@ -24,7 +25,7 @@ class SieveConditionWidget : public QWidget
     Q_OBJECT
 public:
     explicit SieveConditionWidget(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent);
-    ~SieveConditionWidget();
+    ~SieveConditionWidget() override;
 
     void updateAddRemoveButton(bool addButtonEnabled, bool removeButtonEnabled);
     void generatedScript(QString &script, QStringList &required, bool inForEveryPartLoop);
@@ -59,7 +60,7 @@ class SieveConditionWidgetLister : public KPIM::KWidgetLister
     Q_OBJECT
 public:
     explicit SieveConditionWidgetLister(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QWidget *parent = nullptr);
-    ~SieveConditionWidgetLister();
+    ~SieveConditionWidgetLister() override;
 
     void generatedScript(QString &script, int &numberOfCondition, QStringList &requireModules, bool inForEveryPartLoop);
     int conditionNumber() const;
