@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef SIEVESCRIPTBLOCKWIDGET_H
 #define SIEVESCRIPTBLOCKWIDGET_H
 
-#include "sievewidgetpageabstract.h"
 #include "sieveglobalvariablewidget.h"
+#include "sievewidgetpageabstract.h"
 
 class QRadioButton;
 class QGroupBox;
@@ -17,7 +17,8 @@ class QComboBox;
 class QPushButton;
 class QXmlStreamReader;
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveConditionWidgetLister;
 class SieveActionWidgetLister;
 class SieveEditorGraphicalModeWidget;
@@ -26,11 +27,7 @@ class SieveScriptBlockWidget : public SieveWidgetPageAbstract
 {
     Q_OBJECT
 public:
-    enum MatchCondition {
-        OrCondition,
-        AndCondition,
-        AllCondition
-    };
+    enum MatchCondition { OrCondition, AndCondition, AllCondition };
 
     explicit SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *graphicalModeWidget, QWidget *parent = nullptr);
     ~SieveScriptBlockWidget() override;
