@@ -1,33 +1,33 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sievescriptparsingerrordialog.h"
-#include <PimCommon/PimUtil>
 #include <KPIMTextEdit/RichTextEditorWidget>
+#include <PimCommon/PimUtil>
 
 #include <KLocalizedString>
 #include <KSharedConfig>
 
-#include <errno.h>
 #include <KConfigGroup>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <errno.h>
 using namespace KSieveUi;
 SieveScriptParsingErrorDialog::SieveScriptParsingErrorDialog(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Sieve Parsing Error"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
     mTextEdit = new KPIMTextEdit::RichTextEditorWidget(this);
     mTextEdit->setReadOnly(true);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
-    auto *user1Button = new QPushButton(this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
+    auto user1Button = new QPushButton(this);
     buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &SieveScriptParsingErrorDialog::reject);
     user1Button->setText(i18n("Save As..."));
@@ -70,6 +70,5 @@ void SieveScriptParsingErrorDialog::writeConfig()
 void SieveScriptParsingErrorDialog::slotSaveAs()
 {
     const QString filter = i18n("All Files (*)");
-    PimCommon::Util::saveTextAs(mTextEdit->toPlainText(), filter, this, QUrl(),
-                                i18nc("@title:window", "Save Log To File"));
+    PimCommon::Util::saveTextAs(mTextEdit->toPlainText(), filter, this, QUrl(), i18nc("@title:window", "Save Log To File"));
 }
