@@ -1,30 +1,22 @@
-/* Copyright (c) 2011-2018 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KSIEVE_KSIEVEUI_SIEVEEDITOR_H
 #define KSIEVE_KSIEVEUI_SIEVEEDITOR_H
 
 #include "ksieveui_export.h"
-
 #include <QDialog>
-namespace KSieveUi {
+#include <memory>
+namespace KSieveUi
+{
 class SieveEditorPrivate;
 class SieveImapAccountSettings;
+/**
+ * @brief The SieveEditor class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KSIEVEUI_EXPORT SieveEditor : public QDialog
 {
     Q_OBJECT
@@ -32,8 +24,8 @@ public:
     explicit SieveEditor(QWidget *parent = nullptr);
     ~SieveEditor() override;
 
-    QString script() const;
-    QString originalScript() const;
+    Q_REQUIRED_RESULT QString script() const;
+    Q_REQUIRED_RESULT QString originalScript() const;
     void setScript(const QString &script, bool clearUndoRedo = false);
     void setDebugScript(const QString &debug);
     void addFailedMessage(const QString &err);
@@ -58,13 +50,14 @@ Q_SIGNALS:
 protected:
     bool event(QEvent *e) override;
     void closeEvent(QCloseEvent *e) override;
+
 private:
     void slotEnableButtonOk(bool b);
     void slotAccepted();
     void slotCanceled();
     void writeConfig();
     void readConfig();
-    SieveEditorPrivate *const d;
+    std::unique_ptr<SieveEditorPrivate> const d;
 };
 }
 
