@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -6,17 +6,18 @@
 #ifndef SIEVEEDITORABSTRACTWIDGET_H
 #define SIEVEEDITORABSTRACTWIDGET_H
 
-#include <QWidget>
 #include "../util/sieveimapaccountsettings.h"
 #include "ksieveui_private_export.h"
-namespace KSieveUi {
+#include <QWidget>
+namespace KSieveUi
+{
 class SieveImapAccountSettings;
 class KSIEVEUI_TESTS_EXPORT SieveEditorAbstractWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit SieveEditorAbstractWidget(QWidget *parent = nullptr);
-    ~SieveEditorAbstractWidget();
+    ~SieveEditorAbstractWidget() override;
 
     Q_REQUIRED_RESULT virtual QString currentscript();
     virtual void setImportScript(const QString &);
