@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -13,7 +13,8 @@
 class QStackedWidget;
 class QLineEdit;
 class QAction;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveImapAccountSettings;
 class SieveEditorTextModeWidget;
 class SieveEditorGraphicalModeWidget;
@@ -26,12 +27,8 @@ class KSIEVEUI_EXPORT SieveEditorWidget : public QWidget
     Q_OBJECT
 public:
     explicit SieveEditorWidget(bool useMenuBar, QWidget *parent = nullptr);
-    ~SieveEditorWidget();
-    enum EditorMode {
-        Unknown = -1,
-        TextMode = 0,
-        GraphicMode = 1
-    };
+    ~SieveEditorWidget() override;
+    enum EditorMode { Unknown = -1, TextMode = 0, GraphicMode = 1 };
 
     void setReadOnly(bool b);
     Q_REQUIRED_RESULT QString script() const;
@@ -109,6 +106,7 @@ Q_SIGNALS:
     void copyAvailable(bool);
     void changeModeEditor(bool);
     void sieveEditorTabCurrentChanged();
+
 private:
     void slotEnableButtonOk(bool b);
     void slotGenerateXml();
