@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -16,7 +16,7 @@ SieveInfoWidget::SieveInfoWidget(QWidget *parent)
     : QWidget(parent)
     , mInfo(new QTextEdit(this))
 {
-    auto *lay = new QHBoxLayout(this);
+    auto lay = new QHBoxLayout(this);
     lay->setContentsMargins({});
     mInfo->setReadOnly(true);
     mInfo->setAcceptRichText(true);
