@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,17 +7,18 @@
 #ifndef SIEVEINFOWIDGET_H
 #define SIEVEINFOWIDGET_H
 
-#include <QWidget>
 #include "ksieveui_export.h"
+#include <QWidget>
 class QTextEdit;
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class KSIEVEUI_EXPORT SieveInfoWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit SieveInfoWidget(QWidget *parent = nullptr);
-    ~SieveInfoWidget();
+    ~SieveInfoWidget() override;
 
     void setServerInfo(QStringList info);
 
