@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+/* SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -8,7 +8,8 @@
 
 #include <QWidget>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveTextEdit;
 
 class SieveLineNumberArea : public QWidget
