@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,18 +7,19 @@
 #ifndef SIEVESCRIPTDEBUGGERDIALOG_H
 #define SIEVESCRIPTDEBUGGERDIALOG_H
 
-#include <QDialog>
 #include "ksieveui_private_export.h"
+#include <QDialog>
 
 class QPushButton;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveScriptDebuggerWidget;
 class KSIEVEUI_TESTS_EXPORT SieveScriptDebuggerDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit SieveScriptDebuggerDialog(QWidget *parent = nullptr);
-    ~SieveScriptDebuggerDialog();
+    ~SieveScriptDebuggerDialog() override;
 
     void setScript(const QString &script);
     Q_REQUIRED_RESULT QString script() const;
