@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef VACATIONMAILACTIONWIDGET_H
 #define VACATIONMAILACTIONWIDGET_H
 
-#include <QWidget>
 #include "vacation/vacationutils.h"
+#include <QWidget>
 class QStackedWidget;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class AbstractMoveImapFolderWidget;
 class SieveImapAccountSettings;
 class AbstractSelectEmailLineEdit;
@@ -19,7 +20,7 @@ class VacationMailActionWidget : public QWidget
     Q_OBJECT
 public:
     explicit VacationMailActionWidget(QWidget *parent = nullptr);
-    ~VacationMailActionWidget();
+    ~VacationMailActionWidget() override;
 
     void setSieveImapAccountSettings(const KSieveUi::SieveImapAccountSettings &account);
     void mailActionChanged(KSieveUi::VacationUtils::MailAction action);
