@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,10 +7,11 @@
 #ifndef MANAGESIEVETREEVIEW_H
 #define MANAGESIEVETREEVIEW_H
 
-#include <PimCommon/CustomTreeView>
 #include "ksieveui_export.h"
+#include <PimCommon/CustomTreeView>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 /**
  * @brief The ManageSieveTreeView class
  * @author Laurent Montel <montel@kde.org>
@@ -20,7 +21,7 @@ class KSIEVEUI_EXPORT ManageSieveTreeView : public PimCommon::CustomTreeView
     Q_OBJECT
 public:
     explicit ManageSieveTreeView(QWidget *parent = nullptr);
-    ~ManageSieveTreeView();
+    ~ManageSieveTreeView() override;
 
     void setNoImapFound(bool found);
     void setNetworkDown(bool state);
